@@ -1,10 +1,10 @@
+from __future__ import annotations
+
 import matplotlib as mpl
-from matplotlib import rcParams
-import matplotlib.transforms as mtransforms
 import matplotlib.pyplot as plt
 import matplotlib.text as mtext
-
-import mplhep
+import matplotlib.transforms as mtransforms
+from matplotlib import rcParams
 
 
 class ExpText(mtext.Text):
@@ -31,6 +31,7 @@ def exp_text(
     ax=None,
     fontname=None,
     fontsize=None,
+    exp_weight="bold",
     italic=(False, False),
     pad=0,
 ):
@@ -52,6 +53,8 @@ def exp_text(
             Name of font to be used.
         fontsize : string, optional
             Defines size of "secondary label". Experiment label is 1.3x larger.
+        exp_weight : string, optional
+            Set fontweight of <exp> label. Default "bold".
         italic : (bool, bool), optional
             Tuple of bools to switch which label is italicized
         pad : float, optional
@@ -132,7 +135,7 @@ def exp_text(
         ha="left",
         va=loc1_dict[_exp_loc]["va"],
         fontsize=_font_size * 1.3,
-        fontweight="bold",
+        fontweight=exp_weight,
         fontstyle="italic" if italic[0] else "normal",
         fontname=fontname,
     )
@@ -226,14 +229,14 @@ def exp_label(
     loc=0,
     *,
     data=False,
-    paper=False,
-    supplementary=False,
+    label="",
     year=None,
     lumi=None,
     llabel=None,
     rlabel=None,
     fontname=None,
     fontsize=None,
+    exp_weight="bold",
     pad=0,
     italic=(False, False),
     ax=None,
@@ -252,24 +255,25 @@ def exp_label(
         ax : matplotlib.axes.Axes, optional
             Axes object (if None, last one is fetched)
         data : bool, optional
-            Prevents appending "Simulation" to experiment label.
-        paper : bool, optional
-            Prevents appending "Preliminary" to experiment label.
-        supplementary : bool, optional
-            Appends "Supplementary" to experiment label for public plots, included
-            in supplementary materials, but not paper body.
+            Prevents prepending "Simulation" to experiment label. Default ``False``.
+        label : str, optional
+            Text to append after <exp> (Simulation) <label>. Typically "Preliminary"
+            "Supplementary", "Private Work" or "Work in Progress"
         year : int, optional
             Year when data was collected
         lumi : float, optional
             Aggregate luminosity shown. Should require ``"data"`` to be ``True``.
         llabel : string, optional
-            String to manually set left-hand label text.
+            String to manually set left-hand label text. Will overwrite "data" and
+            "label" kwargs.
         rlabel : string, optional
             String to manually set right-hand label text.
         fontname : string, optional
             Name of font to be used.
         fontsize : string, optional
             Defines size of "secondary label". Experiment label is 1.3x larger.
+        exp_weight : string, optional
+            Set fontweight of <exp> label. Default "bold".
         italic : (bool, bool), optional
             Tuple of bools to switch which label is italicized
         pad : float, optional
@@ -306,12 +310,9 @@ def exp_label(
     else:
         _label = ""
         if not data:
-            _label = " ".join(["Simulation", _label])
-        if not paper:
-            _label = " ".join([_label, "Preliminary"])
-        if supplementary:
-            _label = " ".join([_label, "Supplementary"])
-
+            _label = " ".join(["Simulation", label])
+        else:
+            _label = label
         _label = " ".join(_label.split())
 
     exptext, expsuffix = exp_text(
@@ -331,7 +332,12 @@ def exp_label(
             units="inches",
             fig=ax.figure,
         )
-        _lumi = r"$\sqrt{s} = \mathrm{13\ TeV}, " + str(lumi) + r"\ \mathrm{fb}^{-1}$"
+        if lumi is not None:
+            _lumi = (
+                r"$\sqrt{s} = \mathrm{13\ TeV}, " + str(lumi) + r"\ \mathrm{fb}^{-1}$"
+            )
+        else:
+            _lumi = r"$\sqrt{s} = \mathrm{13\ TeV}$"
         explumi = ExpSuffix(
             *exptext.get_position(),
             text=rlabel if rlabel is not None else _lumi,
@@ -346,3 +352,85 @@ def exp_label(
         return exptext, expsuffix, explumi
 
     return exptext, expsuffix
+
+
+def savelabels(
+    fname: str,
+    ax: plt.Axes | None = None,
+    labels: list[str] | dict[str, str] | None = None,
+    **kwargs,
+):
+    """
+    Save multiple copies of a figure on which axes is located with the
+    most commonly used label combinations (or user supplied).
+
+    Example:
+        >>> import mplhep as hep
+        >>> hep.cms.label(data=False)
+        >>> hep.savelabels('test.png')
+
+        This will produces 4 variation on experiment label:
+            - "" -> "test.png"
+            - "Preliminary" -> "test_pas.png"
+            - "Supplementary" -> "test_supp.png"
+            - "Work in Progress" -> "test_wip.png"
+
+        Or the combination of labels and filenames can be set manually
+
+        >>> hep.savelabels('test', labels={"FOO": "foo.pdf", "BAR": "bar"})
+
+        Which will produce:
+        - "FOO" -> "foo.pdf"
+        - "BAR" -> "test_bar.png"
+
+        Passing a list of labels will generate file suffixes by casting
+        to snakecase.
+
+    Parameters
+    ----------
+    fname : str
+        Primary filename to be passed to ``plt.savefig``.
+    ax : matplotlib.axes.Axes, optional
+            Axes object (if None, last one is fetched)
+    labels : dict or list, optional
+        Mapping of label versions to be produced along with desired savename
+        modifications. By default:
+        {
+            "": "",
+            "Preliminary": "pas",
+            "Supplementary": "supp",
+            "Work in Progress": "wip"
+        }
+        If supplied strings contain suffixes such as ".png" the names will be assumed
+        to be absolute and will not incorporate ``fname``.
+        If current label contains "Simulation" this will be perserved.
+    """
+    if labels is None:
+        labels = {
+            "": "",
+            "Preliminary": "pas",
+            "Supplementary": "supp",
+            "Work in Progress": "wip",
+        }
+    if isinstance(labels, list):
+        labels = {label: label.replace(" ", "_").lower() for label in labels}
+    if ax is None:
+        ax = plt.gca()
+
+    label = [ch for ch in ax.get_children() if isinstance(ch, ExpSuffix)][0]
+    _sim = "Simulation" if "Simulation" in label.get_text() else ""
+
+    for label_text, suffix in labels.items():
+        label.set_text(" ".join([_sim, label_text]).lstrip())
+
+        if "." in suffix:
+            save_name = suffix
+        else:
+            if len(suffix) > 0:
+                suffix = "_" + suffix
+            if "." in fname:
+                save_name = f"{fname.split('.')[0]}{suffix}.{fname.split('.')[1]}"
+            else:
+                save_name = f"{fname}{suffix}"
+
+        ax.figure.savefig(save_name, **kwargs)
