@@ -16,10 +16,13 @@ based on the works of Kevin Dungs, Tim Head, Thomas Schietinger,
                       Andrew Powell, Chris Parkes, Elena Graverini
                       and Niels Tuning
 """
+from __future__ import annotations
+
 import inspect
 
-import mplhep
 from matplotlib import docstring
+
+import mplhep
 from mplhep import label as label_base
 
 from .label import lumitext
@@ -28,48 +31,37 @@ from .styles import lhcb as style
 __all__ = ("style", "lumitext", "label", "text")
 
 
-def _lhcb_text(text="", **kwargs):
+@docstring.copy(label_base.exp_text)
+def text(text="", **kwargs):
     for key, value in dict(mplhep.rcParams.text._get_kwargs()).items():
         if (
             value is not None
             and key not in kwargs.keys()
             and key in inspect.getfullargspec(label_base.exp_text).kwonlyargs
         ):
-            kwargs[key] = value
-    return label_base.exp_text(
-        "LHCb",
-        text=text,
-        italic=(False, False),
-        fontsize=28,
-        fontname="Times New Roman",
-        loc=1,
-        **kwargs
-    )
+            kwargs.setdefault(key, value)
+    kwargs.setdefault("italic", (False, False))
+    kwargs.setdefault("fontsize", 28)
+    kwargs.setdefault("fontname", "Times New Roman")
+    kwargs.setdefault("loc", 1)
+    kwargs.setdefault("exp_weight", "normal")
+    return label_base.exp_text("LHCb", text=text, **kwargs)
 
 
-def _lhcb_label(**kwargs):
+@docstring.copy(label_base.exp_label)
+def label(label=None, **kwargs):
     for key, value in dict(mplhep.rcParams.label._get_kwargs()).items():
         if (
             value is not None
             and key not in kwargs.keys()
             and key in inspect.getfullargspec(label_base.exp_label).kwonlyargs
         ):
-            kwargs[key] = value
-    return label_base.exp_label(
-        exp="LHCb",
-        italic=(False, False),
-        fontsize=28,
-        fontname="Times New Roman",
-        loc=1,
-        **kwargs
-    )
-
-
-@docstring.copy(label_base.exp_text)
-def text(*args, **kwargs):
-    return _lhcb_text(*args, **kwargs)
-
-
-@docstring.copy(label_base.exp_label)
-def label(**kwargs):
-    return _lhcb_label(**kwargs)
+            kwargs.setdefault(key, value)
+    kwargs.setdefault("italic", (False, False))
+    kwargs.setdefault("fontsize", 28)
+    kwargs.setdefault("fontname", "Times New Roman")
+    kwargs.setdefault("exp_weight", "normal")
+    kwargs.setdefault("loc", 1)
+    if label is not None:
+        kwargs["label"] = label
+    return label_base.exp_label("LHCb", **kwargs)
